==> cryptlex_python_sdk-1.0.2.tar.gz: cryptlex_python_sdk-1.0.2/src/cryptlex_web_api_client/api/webhooks/getv3webhooksevents.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.getv_3_webhooksevents_response_200 import Getv3WebhookseventsResponse200
from ...models.http_error_response_dto import HttpErrorResponseDto
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/v3/webhooks/events".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[Union[Getv3WebhookseventsResponse200, HttpErrorResponseDto]]:
    if response.status_code == 200:
        response_200 = Getv3WebhookseventsResponse200.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = HttpErrorResponseDto.from_dict(response.json())

        return response_401
    if response.status_code == 403:
        response_403 = HttpErrorResponseDto.from_dict(response.json())

        return response_403
    if response.status_code == 429:
        response_429 = HttpErrorResponseDto.from_dict(response.json())

        return response_429
    if response.status_code == 500:
        response_500 = HttpErrorResponseDto.from_dict(response.json())

        return response_500
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[Union[Getv3WebhookseventsResponse200, HttpErrorResponseDto]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
) -> Response[Union[Getv3WebhookseventsResponse200, HttpErrorResponseDto]]:
    kwargs = _get_kwargs(
        client=client,
    )

    response = httpx.get(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
) -> Optional[Union[Getv3WebhookseventsResponse200, HttpErrorResponseDto]]:
    """Returns a list of all the events which can be subscribed to using webhooks."""

    return sync_detailed(
        client=client,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
) -> Response[Union[Getv3WebhookseventsResponse200, HttpErrorResponseDto]]:
    kwargs = _get_kwargs(
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
) -> Optional[Union[Getv3WebhookseventsResponse200, HttpErrorResponseDto]]:
    """Returns a list of all the events which can be subscribed to using webhooks."""

    return (
        await asyncio_detailed(
            client=client,
        )
    ).parsed

==> cryptlex_python_sdk-1.0.3.tar.gz: cryptlex_python_sdk-1.0.3/src/cryptlex_web_api_client/api/webhooks/getv3webhooksevents.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.getv_3_webhooksevents_response_200 import Getv3WebhookseventsResponse200
from ...models.http_error_response_dto import HttpErrorResponseDto
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/v3/webhooks/events".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[Union[Getv3WebhookseventsResponse200, HttpErrorResponseDto]]:
    if response.status_code == 200:
        response_200 = Getv3WebhookseventsResponse200.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = HttpErrorResponseDto.from_dict(response.json())

        return response_401
    if response.status_code == 403:
        response_403 = HttpErrorResponseDto.from_dict(response.json())

        return response_403
    if response.status_code == 429:
        response_429 = HttpErrorResponseDto.from_dict(response.json())

        return response_429
    if response.status_code == 500:
        response_500 = HttpErrorResponseDto.from_dict(response.json())

        return response_500
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[Union[Getv3WebhookseventsResponse200, HttpErrorResponseDto]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
) -> Response[Union[Getv3WebhookseventsResponse200, HttpErrorResponseDto]]:
    """List all events

     Returns a list of all the events which can be subscribed to using webhooks.

    Returns:
        Response[Union[Getv3WebhookseventsResponse200, HttpErrorResponseDto]]
    """

    kwargs = _get_kwargs(
        client=client,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
) -> Optional[Union[Getv3WebhookseventsResponse200, HttpErrorResponseDto]]:
    """List all events

     Returns a list of all the events which can be subscribed to using webhooks.

    Returns:
        Response[Union[Getv3WebhookseventsResponse200, HttpErrorResponseDto]]
    """

    return sync_detailed(
        client=client,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
) -> Response[Union[Getv3WebhookseventsResponse200, HttpErrorResponseDto]]:
    """List all events

     Returns a list of all the events which can be subscribed to using webhooks.

    Returns:
        Response[Union[Getv3WebhookseventsResponse200, HttpErrorResponseDto]]
    """

    kwargs = _get_kwargs(
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
) -> Optional[Union[Getv3WebhookseventsResponse200, HttpErrorResponseDto]]:
    """List all events

     Returns a list of all the events which can be subscribed to using webhooks.

    Returns:
        Response[Union[Getv3WebhookseventsResponse200, HttpErrorResponseDto]]
    """

    return (
        await asyncio_detailed(
            client=client,
        )
    ).parsed
